import { Controller, Get, Query, Post, Body } from '@nestjs/common'
import { ApiOperation, ApiTags } from '@nestjs/swagger'

import {
  CreateAgentTaskDto,
  GetAgentTaskListDto,
  GetAgentTaskDetailDto
} from '@/dto/agent-execution'

import { AgentExecutionService } from './service/agent-execution.service'

@ApiTags('agent-execution')
@Controller('agent-execution')
export class AgentExecutionController {
  constructor(private readonly agentExecutionService: AgentExecutionService) {}

  @Post('create-agent-task')
  @ApiOperation({ summary: '创建任务' })
  async createAgentTask(@Body() body: CreateAgentTaskDto) {
    return this.agentExecutionService.createAgentTask(body)
  }

  @Get('get-agent-task-list')
  @ApiOperation({ summary: '获取任务列表' })
  async getAgentTaskList(@Query() query: GetAgentTaskListDto) {
    return this.agentExecutionService.getAgentTaskList(query)
  }

  @Get('get-agent-task-detail')
  @ApiOperation({ summary: '获取任务详情' })
  async getAgentTaskDetail(@Query() query: GetAgentTaskDetailDto) {
    return this.agentExecutionService.getAgentTaskDetail(query)
  }
}
